/*
 * Copyright (c) 2009 - 2019 Deutsches Elektronen-Synchroton,
 * Member of the Helmholtz Association, (DESY), HAMBURG, GERMANY
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program (see the file COPYING.LIB for more
 * details); if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.dcache.nfs.v4;

import java.io.IOException;
import org.dcache.nfs.ChimeraNFSException;
import org.dcache.nfs.v4.xdr.nfs_argop4;
import org.dcache.nfs.v4.xdr.nfs_resop4;
import org.dcache.oncrpc4j.rpc.OncRpcException;

/**
 *
 * NFSv4 operation abstraction
 *
 */
public abstract class AbstractNFSv4Operation {

    protected final nfs_argop4 _args;

    public AbstractNFSv4Operation(nfs_argop4 args, int opCode) {
        _args = args;
    }

    /**
     * Process current operation. The {@code result} object is used to store
     * result of the operation execution.
     * @param context the context of compound request of this operation.
     * @param result the operation result object to use.
     * @throws ChimeraNFSException when a specific NFS error is returned
     * @throws IOException when NFS non specific errors occur
     * @throws OncRpcException if requests arguments can't be decoded.
     */
    public abstract void  process(CompoundContext context, nfs_resop4 result)
            throws ChimeraNFSException, IOException, OncRpcException;
}
